@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2018 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) Zend Technologies Ltd. (http://www.zend.com)           |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -22,7 +22,7 @@
 #include <zend.h>
 #include <zend_vm_opcodes.h>
 
-static const char *zend_vm_opcodes_names[199] = {
+static const char *zend_vm_opcodes_names[195] = {
 	"ZEND_NOP",
 	"ZEND_ADD",
 	"ZEND_SUB",
@@ -35,6 +35,7 @@ static const char *zend_vm_opcodes_names[199] = {
 	"ZEND_BW_OR",
 	"ZEND_BW_AND",
 	"ZEND_BW_XOR",
+	"ZEND_POW",
 	"ZEND_BW_NOT",
 	"ZEND_BOOL_NOT",
 	"ZEND_BOOL_XOR",
@@ -44,27 +45,26 @@ static const char *zend_vm_opcodes_names[199] = {
 	"ZEND_IS_NOT_EQUAL",
 	"ZEND_IS_SMALLER",
 	"ZEND_IS_SMALLER_OR_EQUAL",
-	"ZEND_CAST",
+	"ZEND_ASSIGN",
+	"ZEND_ASSIGN_DIM",
+	"ZEND_ASSIGN_OBJ",
+	"ZEND_ASSIGN_STATIC_PROP",
+	"ZEND_ASSIGN_OP",
+	"ZEND_ASSIGN_DIM_OP",
+	"ZEND_ASSIGN_OBJ_OP",
+	"ZEND_ASSIGN_STATIC_PROP_OP",
+	"ZEND_ASSIGN_REF",
 	"ZEND_QM_ASSIGN",
-	"ZEND_ASSIGN_ADD",
-	"ZEND_ASSIGN_SUB",
-	"ZEND_ASSIGN_MUL",
-	"ZEND_ASSIGN_DIV",
-	"ZEND_ASSIGN_MOD",
-	"ZEND_ASSIGN_SL",
-	"ZEND_ASSIGN_SR",
-	"ZEND_ASSIGN_CONCAT",
-	"ZEND_ASSIGN_BW_OR",
-	"ZEND_ASSIGN_BW_AND",
-	"ZEND_ASSIGN_BW_XOR",
+	"ZEND_ASSIGN_OBJ_REF",
+	"ZEND_ASSIGN_STATIC_PROP_REF",
 	"ZEND_PRE_INC",
 	"ZEND_PRE_DEC",
 	"ZEND_POST_INC",
 	"ZEND_POST_DEC",
-	"ZEND_ASSIGN",
-	"ZEND_ASSIGN_REF",
-	"ZEND_ECHO",
-	"ZEND_GENERATOR_CREATE",
+	"ZEND_PRE_INC_STATIC_PROP",
+	"ZEND_PRE_DEC_STATIC_PROP",
+	"ZEND_POST_INC_STATIC_PROP",
+	"ZEND_POST_DEC_STATIC_PROP",
 	"ZEND_JMP",
 	"ZEND_JMPZ",
 	"ZEND_JMPNZ",
@@ -74,7 +74,7 @@ static const char *zend_vm_opcodes_names[199] = {
 	"ZEND_CASE",
 	"ZEND_CHECK_VAR",
 	"ZEND_SEND_VAR_NO_REF_EX",
-	"ZEND_MAKE_REF",
+	"ZEND_CAST",
 	"ZEND_BOOL",
 	"ZEND_FAST_CONCAT",
 	"ZEND_ROPE_INIT",
@@ -159,26 +159,26 @@ static const char *zend_vm_opcodes_names[199] = {
 	"ZEND_PRE_DEC_OBJ",
 	"ZEND_POST_INC_OBJ",
 	"ZEND_POST_DEC_OBJ",
-	"ZEND_ASSIGN_OBJ",
+	"ZEND_ECHO",
 	"ZEND_OP_DATA",
 	"ZEND_INSTANCEOF",
-	"ZEND_DECLARE_CLASS",
-	"ZEND_DECLARE_INHERITED_CLASS",
+	"ZEND_GENERATOR_CREATE",
+	"ZEND_MAKE_REF",
 	"ZEND_DECLARE_FUNCTION",
-	"ZEND_YIELD_FROM",
+	"ZEND_DECLARE_LAMBDA_FUNCTION",
 	"ZEND_DECLARE_CONST",
-	"ZEND_ADD_INTERFACE",
-	"ZEND_DECLARE_INHERITED_CLASS_DELAYED",
-	"ZEND_VERIFY_ABSTRACT_CLASS",
-	"ZEND_ASSIGN_DIM",
+	"ZEND_DECLARE_CLASS",
+	"ZEND_DECLARE_CLASS_DELAYED",
+	"ZEND_DECLARE_ANON_CLASS",
+	"ZEND_ADD_ARRAY_UNPACK",
 	"ZEND_ISSET_ISEMPTY_PROP_OBJ",
 	"ZEND_HANDLE_EXCEPTION",
 	"ZEND_USER_OPCODE",
 	"ZEND_ASSERT_CHECK",
 	"ZEND_JMP_SET",
-	"ZEND_DECLARE_LAMBDA_FUNCTION",
-	"ZEND_ADD_TRAIT",
-	"ZEND_BIND_TRAITS",
+	"ZEND_UNSET_CV",
+	"ZEND_ISSET_ISEMPTY_CV",
+	"ZEND_FETCH_LIST_W",
 	"ZEND_SEPARATE",
 	"ZEND_FETCH_CLASS_NAME",
 	"ZEND_CALL_TRAMPOLINE",
@@ -189,13 +189,13 @@ static const char *zend_vm_opcodes_names[199] = {
 	"ZEND_FAST_RET",
 	"ZEND_RECV_VARIADIC",
 	"ZEND_SEND_UNPACK",
-	"ZEND_POW",
-	"ZEND_ASSIGN_POW",
+	"ZEND_YIELD_FROM",
+	"ZEND_COPY_TMP",
 	"ZEND_BIND_GLOBAL",
 	"ZEND_COALESCE",
 	"ZEND_SPACESHIP",
-	"ZEND_DECLARE_ANON_CLASS",
-	"ZEND_DECLARE_ANON_INHERITED_CLASS",
+	"ZEND_FUNC_NUM_ARGS",
+	"ZEND_FUNC_GET_ARGS",
 	"ZEND_FETCH_STATIC_PROP_R",
 	"ZEND_FETCH_STATIC_PROP_W",
 	"ZEND_FETCH_STATIC_PROP_RW",
@@ -217,26 +217,23 @@ static const char *zend_vm_opcodes_names[199] = {
 	"ZEND_GET_CLASS",
 	"ZEND_GET_CALLED_CLASS",
 	"ZEND_GET_TYPE",
-	"ZEND_FUNC_NUM_ARGS",
-	"ZEND_FUNC_GET_ARGS",
-	"ZEND_UNSET_CV",
-	"ZEND_ISSET_ISEMPTY_CV",
-	"ZEND_FETCH_LIST_W",
+	"ZEND_ARRAY_KEY_EXISTS",
 };
 
-static uint32_t zend_vm_opcodes_flags[199] = {
+static uint32_t zend_vm_opcodes_flags[195] = {
 	0x00000000,
+	0x00000b0b,
+	0x00000b0b,
+	0x80000b0b,
 	0x00000707,
-	0x00000707,
-	0x80000707,
-	0x00000707,
-	0x00000707,
-	0x00000707,
-	0x00000707,
+	0x00000b0b,
+	0x00000b0b,
+	0x00000b0b,
 	0x40000707,
-	0x80000707,
-	0x80000707,
-	0x80000707,
+	0x80000b0b,
+	0x80000b0b,
+	0x80000b0b,
+	0x00000707,
 	0x00000007,
 	0x00000007,
 	0x80000707,
@@ -244,29 +241,28 @@ static uint32_t zend_vm_opcodes_flags[199] = {
 	0x80000303,
 	0x80000707,
 	0x80000707,
-	0x00000707,
-	0x00000707,
-	0x07000003,
-	0x00000003,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x04046751,
-	0x00000001,
-	0x00000001,
-	0x00000001,
-	0x00000001,
+	0x00000b0b,
+	0x00000b0b,
 	0x00000301,
+	0x00006701,
+	0x00040751,
+	0x00040000,
+	0x04000701,
+	0x04006701,
+	0x04000751,
+	0x04000000,
 	0x0b000101,
-	0x00000007,
-	0x00000000,
+	0x00000003,
+	0x0b040751,
+	0x0b040000,
+	0x00000001,
+	0x00000001,
+	0x00000001,
+	0x00000001,
+	0x00040000,
+	0x00040000,
+	0x00040000,
+	0x00040000,
 	0x00000020,
 	0x00002007,
 	0x00002007,
@@ -276,7 +272,7 @@ static uint32_t zend_vm_opcodes_flags[199] = {
 	0x00000705,
 	0x00000101,
 	0x00001001,
-	0x00000101,
+	0x07000003,
 	0x00000007,
 	0x00000707,
 	0x01000701,
@@ -304,13 +300,13 @@ static uint32_t zend_vm_opcodes_flags[199] = {
 	0x00040751,
 	0x00002003,
 	0x03000001,
-	0x00000007,
+	0x00000000,
 	0x00010107,
 	0x00000707,
 	0x00040757,
 	0x00010107,
 	0x00006701,
-	0x00040751,
+	0x00640751,
 	0x00010107,
 	0x00006701,
 	0x00040751,
@@ -319,7 +315,7 @@ static uint32_t zend_vm_opcodes_flags[199] = {
 	0x00040757,
 	0x00010107,
 	0x00006703,
-	0x00040753,
+	0x00240753,
 	0x00010107,
 	0x00000701,
 	0x00040751,
@@ -361,26 +357,26 @@ static uint32_t zend_vm_opcodes_flags[199] = {
 	0x00040751,
 	0x00040751,
 	0x00040751,
-	0x00040751,
+	0x00000007,
 	0x00000000,
 	0x00047305,
+	0x00000000,
+	0x00000101,
+	0x00000000,
+	0x00040103,
+	0x00000303,
 	0x00000003,
 	0x00000303,
+	0x00040000,
 	0x00000000,
-	0x00000003,
-	0x00000303,
-	0x00040300,
-	0x00000303,
-	0x00000000,
-	0x00006701,
 	0x00060757,
 	0x00000000,
 	0x00000000,
 	0x00002000,
 	0x00002003,
-	0x00000103,
-	0x00040000,
-	0x00000000,
+	0x00000101,
+	0x00020101,
+	0x00000701,
 	0x00000101,
 	0x00000071,
 	0x00000000,
@@ -391,39 +387,35 @@ static uint32_t zend_vm_opcodes_flags[199] = {
 	0x00003000,
 	0x0000a110,
 	0x00000000,
-	0x00000707,
-	0x04046751,
+	0x00000003,
+	0x00000105,
 	0x00040301,
-	0x00002007,
+	0x00002003,
 	0x00000707,
-	0x03000000,
-	0x03000303,
-	0x00047307,
-	0x00047307,
-	0x00047307,
-	0x00047307,
-	0x00047307,
-	0x00047307,
-	0x00047307,
-	0x00067307,
+	0x00000101,
+	0x00000103,
+	0x00047000,
+	0x00647000,
+	0x00047000,
+	0x00047000,
+	0x00247000,
+	0x00047000,
+	0x00040000,
+	0x00067000,
 	0x00040373,
 	0x00100101,
-	0x00100301,
+	0x00100101,
 	0x00000101,
 	0x00001001,
 	0x00000101,
 	0x0300030b,
 	0x0300030b,
 	0x01000303,
-	0x00000103,
-	0x00000103,
+	0x00000107,
+	0x00000107,
 	0x00000101,
 	0x00000103,
-	0x00000101,
-	0x00000103,
-	0x00000101,
-	0x00020101,
-	0x00000701,
+	0x00000707,
 };
 
 ZEND_API const char* ZEND_FASTCALL zend_get_opcode_name(zend_uchar opcode) {
