@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2017 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,8 +16,6 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id$ */
-
 #define ZEND_INCLUDE_FULL_WINDOWS_HEADERS
 
 #ifdef HAVE_CONFIG_H
@@ -88,11 +86,8 @@ static int _php_curl_share_setopt(php_curlsh *sh, zend_long option, zval *zvalue
 	}
 
 	SAVE_CURLSH_ERROR(sh, error);
-	if (error != CURLSHE_OK) {
-		return 1;
-	} else {
-		return 0;
-	}
+
+	return error != CURLSHE_OK;
 }
 /* }}} */
 
@@ -153,7 +148,6 @@ PHP_FUNCTION(curl_share_errno)
 /* }}} */
 
 
-#if LIBCURL_VERSION_NUM >= 0x070c00 /* Available since 7.12.0 */
 /* {{{ proto bool curl_share_strerror(int code)
          return string describing error code */
 PHP_FUNCTION(curl_share_strerror)
@@ -173,15 +167,5 @@ PHP_FUNCTION(curl_share_strerror)
 	}
 }
 /* }}} */
-#endif
 
 #endif
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
