@@ -71,7 +71,7 @@ PHP_FUNCTION( collator_create )
 }
 /* }}} */
 
-/* {{{ proto Collator Collator::__construct( string $locale )
+/* {{{ proto Collator::__construct( string $locale )
  * Collator object constructor.
  */
 PHP_METHOD( Collator, __construct )
@@ -79,7 +79,7 @@ PHP_METHOD( Collator, __construct )
 	zend_error_handling error_handling;
 
 	zend_replace_error_handling(EH_THROW, IntlException_ce_ptr, &error_handling);
-	return_value = getThis();
+	return_value = ZEND_THIS;
 	if (collator_ctor(INTERNAL_FUNCTION_PARAM_PASSTHRU, 1) == FAILURE) {
 		if (!EG(exception)) {
 			zend_throw_exception(IntlException_ce_ptr, "Constructor failed", 0);
@@ -88,12 +88,3 @@ PHP_METHOD( Collator, __construct )
 	zend_restore_error_handling(&error_handling);
 }
 /* }}} */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
