@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -27,17 +27,17 @@ zend_class_entry *Transliterator_ce_ptr = NULL;
 
 zend_object_handlers Transliterator_handlers;
 
-/* {{{ int transliterator_object_construct( zval *object, UTransliterator *utrans, UErrorCode *status TSRMLS_DC )
+/* {{{ int transliterator_object_construct( zval *object, UTransliterator *utrans, UErrorCode *status )
  * Initialize internals of Transliterator_object.
  */
 int transliterator_object_construct( zval *object,
 									 UTransliterator *utrans,
-									 UErrorCode *status TSRMLS_DC )
+									 UErrorCode *status )
 {
 	const UChar           *ustr_id;
 	int32_t               ustr_id_len;
-	char                  *str_id;
-	int                   str_id_len;
+	zend_string           *u8str;
+	zval                  tmp;
 	Transliterator_object *to;
 
 	TRANSLITERATOR_METHOD_FETCH_OBJECT_NO_CHECK;
@@ -49,15 +49,16 @@ int transliterator_object_construct( zval *object,
 	to->utrans = utrans;
 
 	ustr_id = utrans_getUnicodeID( utrans, &ustr_id_len );
-	intl_convert_utf16_to_utf8( &str_id, &str_id_len, ustr_id, (int ) ustr_id_len, status );
-	if( U_FAILURE( *status ) )
+	u8str = intl_convert_utf16_to_utf8(ustr_id, (int ) ustr_id_len, status );
+	if( !u8str )
 	{
 		return FAILURE;
 	}
 
-	zend_update_property_stringl( Transliterator_ce_ptr, object,
-		"id", sizeof( "id" ) - 1, str_id, str_id_len TSRMLS_CC );
-	efree( str_id );
+	ZVAL_NEW_STR(&tmp, u8str);
+	zend_update_property(Transliterator_ce_ptr, object,
+		"id", sizeof( "id" ) - 1, &tmp );
+	GC_DELREF(u8str);
 	return SUCCESS;
 }
 /* }}} */
@@ -69,19 +70,19 @@ int transliterator_object_construct( zval *object,
 /* {{{ void transliterator_object_init( Transliterator_object* to )
  * Initialize internals of Transliterator_object.
  */
-static void transliterator_object_init( Transliterator_object* to TSRMLS_DC )
+static void transliterator_object_init( Transliterator_object* to )
 {
 	if( !to )
 		return;
 
-	intl_error_init( TRANSLITERATOR_ERROR_P( to ) TSRMLS_CC );
+	intl_error_init( TRANSLITERATOR_ERROR_P( to ) );
 }
 /* }}} */
 
 /* {{{ void transliterator_object_destroy( Transliterator_object* to )
  * Clean up mem allocted by internals of Transliterator_object
  */
-static void transliterator_object_destroy( Transliterator_object* to TSRMLS_DC )
+static void transliterator_object_destroy( Transliterator_object* to )
 {
 	if( !to )
 		return;
@@ -92,59 +93,35 @@ static void transliterator_object_destroy( Transliterator_object* to TSRMLS_DC )
 		to->utrans = NULL;
 	}
 
-	intl_error_reset( TRANSLITERATOR_ERROR_P( to ) TSRMLS_CC );
-}
-/* }}} */
-
-/* {{{ Transliterator_objects_dtor */
-static void Transliterator_objects_dtor(
-	void *object,
-	zend_object_handle handle TSRMLS_DC )
-{
-	zend_objects_destroy_object( object, handle TSRMLS_CC );
+	intl_error_reset( TRANSLITERATOR_ERROR_P( to ) );
 }
 /* }}} */
 
 /* {{{ Transliterator_objects_free */
-static void Transliterator_objects_free( zend_object *object TSRMLS_DC )
+static void Transliterator_objects_free( zend_object *object )
 {
-	Transliterator_object* to = (Transliterator_object*) object;
+	Transliterator_object* to = php_intl_transliterator_fetch_object(object);
 
-	zend_object_std_dtor( &to->zo TSRMLS_CC );
+	zend_object_std_dtor( &to->zo );
 
-	transliterator_object_destroy( to TSRMLS_CC );
-
-	efree( to );
+	transliterator_object_destroy( to );
 }
 /* }}} */
 
 /* {{{ Transliterator_object_create */
-static zend_object_value Transliterator_object_create(
-	zend_class_entry *ce TSRMLS_DC )
+static zend_object *Transliterator_object_create( zend_class_entry *ce )
 {
-	zend_object_value      retval;
 	Transliterator_object* intern;
 
-	intern = ecalloc( 1, sizeof( Transliterator_object ) );
+	intern = zend_object_alloc(sizeof(Transliterator_object), ce);
 
-	zend_object_std_init( &intern->zo, ce TSRMLS_CC );
-#if PHP_VERSION_ID < 50399
-    zend_hash_copy( intern->zo.properties, &(ce->default_properties ),
-        (copy_ctor_func_t) zval_add_ref, NULL, sizeof( zval* ) );
-#else
-    object_properties_init( (zend_object*) intern, ce );
-#endif
-	transliterator_object_init( intern TSRMLS_CC );
+	zend_object_std_init( &intern->zo, ce );
+    object_properties_init( &intern->zo, ce );
+	transliterator_object_init( intern );
 
-	retval.handle = zend_objects_store_put(
-		intern,
-		Transliterator_objects_dtor,
-		(zend_objects_free_object_storage_t) Transliterator_objects_free,
-		NULL TSRMLS_CC );
+	intern->zo.handlers = &Transliterator_handlers;
 
-	retval.handlers = &Transliterator_handlers;
-
-	return retval;
+	return &intern->zo;
 }
 /* }}} */
 
@@ -153,60 +130,58 @@ static zend_object_value Transliterator_object_create(
  */
 
 /* {{{ clone handler for Transliterator */
-static zend_object_value Transliterator_clone_obj( zval *object TSRMLS_DC )
+static zend_object *Transliterator_clone_obj( zval *object )
 {
 	Transliterator_object *to_orig,
 	                      *to_new;
-	zend_object_value     ret_val;
-	intl_error_reset( NULL TSRMLS_CC );
+	zend_object 		  *ret_val;
+	intl_error_reset( NULL );
 
-	to_orig = zend_object_store_get_object( object TSRMLS_CC );
-	intl_error_reset( INTL_DATA_ERROR_P( to_orig ) TSRMLS_CC );
-	ret_val = Transliterator_ce_ptr->create_object( Z_OBJCE_P( object ) TSRMLS_CC );
-	to_new  = zend_object_store_get_object_by_handle( ret_val.handle TSRMLS_CC );
+	to_orig = Z_INTL_TRANSLITERATOR_P( object );
+	intl_error_reset( INTL_DATA_ERROR_P( to_orig ) );
+	ret_val = Transliterator_ce_ptr->create_object( Z_OBJCE_P( object ) );
+	to_new  = php_intl_transliterator_fetch_object( ret_val );
 
-	zend_objects_clone_members( &to_new->zo, ret_val,
-		&to_orig->zo, Z_OBJ_HANDLE_P( object ) TSRMLS_CC );
+	zend_objects_clone_members( &to_new->zo, &to_orig->zo );
 
 	if( to_orig->utrans != NULL )
 	{
-		UTransliterator *utrans = NULL;
 		zval			tempz; /* dummy zval to pass to transliterator_object_construct */
 
 		/* guaranteed to return NULL if it fails */
-		utrans = utrans_clone( to_orig->utrans, TRANSLITERATOR_ERROR_CODE_P( to_orig ) );
+		UTransliterator *utrans = utrans_clone( to_orig->utrans, TRANSLITERATOR_ERROR_CODE_P( to_orig ) );
 
 		if( U_FAILURE( TRANSLITERATOR_ERROR_CODE( to_orig ) ) )
 			goto err;
 
-		Z_OBJVAL( tempz ) = ret_val;
+		ZVAL_OBJ(&tempz, ret_val);
 		transliterator_object_construct( &tempz, utrans,
-			TRANSLITERATOR_ERROR_CODE_P( to_orig ) TSRMLS_CC );
+			TRANSLITERATOR_ERROR_CODE_P( to_orig ) );
 
 		if( U_FAILURE( TRANSLITERATOR_ERROR_CODE( to_orig ) ) )
 		{
-			char *err_msg;
+			zend_string *err_msg;
 err:
 
 			if( utrans != NULL )
-				transliterator_object_destroy( to_new TSRMLS_CC );
+				transliterator_object_destroy( to_new );
 
 			/* set the error anyway, in case in the future we decide not to
 			 * throw an error. It also helps build the error message */
-			intl_error_set_code( NULL, INTL_DATA_ERROR_CODE( to_orig ) TSRMLS_CC );
+			intl_error_set_code( NULL, INTL_DATA_ERROR_CODE( to_orig ) );
 			intl_errors_set_custom_msg( TRANSLITERATOR_ERROR_P( to_orig ),
-				"Could not clone transliterator", 0 TSRMLS_CC );
+				"Could not clone transliterator", 0 );
 
-			err_msg = intl_error_get_message( TRANSLITERATOR_ERROR_P( to_orig ) TSRMLS_CC );
-			php_error_docref( NULL TSRMLS_CC, E_ERROR, "%s", err_msg );
-			efree( err_msg ); /* if it's changed into a warning */
+			err_msg = intl_error_get_message( TRANSLITERATOR_ERROR_P( to_orig ) );
+			zend_throw_error( NULL, "%s", ZSTR_VAL(err_msg) );
+			zend_string_free( err_msg ); /* if it's changed into a warning */
 			/* do not destroy tempz; we need to return something */
 		}
 	}
 	else
 	{
 		/* We shouldn't have unconstructed objects in the first place */
-		php_error_docref( NULL TSRMLS_CC, E_WARNING,
+		php_error_docref( NULL, E_WARNING,
 			"Cloning unconstructed transliterator." );
 	}
 
@@ -214,46 +189,30 @@ err:
 }
 /* }}} */
 
-#if PHP_VERSION_ID >= 50399
-# define TRANSLITERATOR_PROPERTY_HANDLER_PROLOG \
+#define TRANSLITERATOR_PROPERTY_HANDLER_PROLOG(return_fail) \
 	zval tmp_member;							\
 	if( Z_TYPE_P( member ) != IS_STRING )		\
 	{											\
-		tmp_member = *member;					\
-		zval_copy_ctor( &tmp_member );			\
-		convert_to_string( &tmp_member );		\
+		zend_string *_str =						\
+			zval_try_get_string_func(member);	\
+		if (UNEXPECTED(!_str)) { return_fail; }	\
+		ZVAL_STR(&tmp_member, _str);			\
 		member = &tmp_member;					\
-		key = NULL;								\
+		cache_slot = NULL;						\
     }
-#else
-# define TRANSLITERATOR_PROPERTY_HANDLER_PROLOG \
-	zval tmp_member;							\
-	if( Z_TYPE_P( member ) != IS_STRING )		\
-	{											\
-		tmp_member = *member;					\
-		zval_copy_ctor( &tmp_member );			\
-		convert_to_string( &tmp_member );		\
-		member = &tmp_member;					\
-    }
-#endif
 
 #define TRANSLITERATOR_PROPERTY_HANDLER_EPILOG	\
-	if( member == &tmp_member )				\
+	if( member == &tmp_member )					\
 	{											\
-		zval_dtor( &tmp_member );				\
+		zval_ptr_dtor_str( &tmp_member );		\
 	}
 
 /* {{{ get_property_ptr_ptr handler */
-#if PHP_VERSION_ID < 50399
-static zval **Transliterator_get_property_ptr_ptr( zval *object, zval *member TSRMLS_DC )
-#else
-static zval **Transliterator_get_property_ptr_ptr( zval *object, zval *member, int type,
-	const struct _zend_literal *key TSRMLS_DC )
-#endif
+static zval *Transliterator_get_property_ptr_ptr( zval *object, zval *member, int type, void **cache_slot )
 {
-	zval **retval;
+	zval *retval;
 
-	TRANSLITERATOR_PROPERTY_HANDLER_PROLOG;
+	TRANSLITERATOR_PROPERTY_HANDLER_PROLOG(return NULL);
 
 	if(zend_binary_strcmp( "id", sizeof( "id" ) - 1,
 		Z_STRVAL_P( member ), Z_STRLEN_P( member ) ) == 0 )
@@ -262,11 +221,7 @@ static zval **Transliterator_get_property_ptr_ptr( zval *object, zval *member, i
 	}
 	else
 	{
-#if PHP_VERSION_ID < 50399
-		retval = std_object_handlers.get_property_ptr_ptr( object, member TSRMLS_CC );
-#else
-		retval = std_object_handlers.get_property_ptr_ptr( object, member, type, key TSRMLS_CC );
-#endif
+		retval = zend_std_get_property_ptr_ptr( object, member, type, cache_slot );
 	}
 
 	TRANSLITERATOR_PROPERTY_HANDLER_EPILOG;
@@ -276,31 +231,22 @@ static zval **Transliterator_get_property_ptr_ptr( zval *object, zval *member, i
 /* }}} */
 
 /* {{{ read_property handler */
-#if PHP_VERSION_ID < 50399
-static zval *Transliterator_read_property( zval *object, zval *member, int type TSRMLS_DC ) /* {{{ */
-#else
-static zval *Transliterator_read_property( zval *object, zval *member, int type,
-	const struct _zend_literal *key TSRMLS_DC ) /* {{{ */
-#endif
+static zval *Transliterator_read_property( zval *object, zval *member, int type, void **cache_slot, zval *rv )
 {
 	zval *retval;
 
-	TRANSLITERATOR_PROPERTY_HANDLER_PROLOG;
+	TRANSLITERATOR_PROPERTY_HANDLER_PROLOG(return &EG(uninitialized_zval));
 
 	if( ( type != BP_VAR_R && type != BP_VAR_IS ) &&
 		( zend_binary_strcmp( "id", sizeof( "id" ) - 1,
 		Z_STRVAL_P( member ), Z_STRLEN_P( member ) ) == 0 ) )
 	{
-		php_error_docref0( NULL TSRMLS_CC, E_WARNING, "The property \"id\" is read-only" );
+		php_error_docref(NULL, E_WARNING, "The property \"id\" is read-only" );
 		retval = &EG( uninitialized_zval );
 	}
 	else
 	{
-#if PHP_VERSION_ID < 50399
-		retval = std_object_handlers.read_property( object, member, type TSRMLS_CC );
-#else
-		retval = std_object_handlers.read_property( object, member, type, key TSRMLS_CC );
-#endif
+		retval = zend_std_read_property( object, member, type, cache_slot, rv );
 	}
 
 	TRANSLITERATOR_PROPERTY_HANDLER_EPILOG;
@@ -311,31 +257,30 @@ static zval *Transliterator_read_property( zval *object, zval *member, int type,
 /* }}} */
 
 /* {{{ write_property handler */
-#if PHP_VERSION_ID < 50399
-static void Transliterator_write_property( zval *object, zval *member, zval *value TSRMLS_DC )
-#else
-static void Transliterator_write_property( zval *object, zval *member, zval *value,
-	const struct _zend_literal *key TSRMLS_DC )
-#endif
+static zval *Transliterator_write_property( zval *object, zval *member, zval *value, void **cache_slot )
 {
-	TRANSLITERATOR_PROPERTY_HANDLER_PROLOG;
+	zend_class_entry *scope;
+	TRANSLITERATOR_PROPERTY_HANDLER_PROLOG(return value);
 
-	if( ( EG( scope ) != Transliterator_ce_ptr ) &&
+	if (EG(fake_scope)) {
+		scope = EG(fake_scope);
+	} else {
+		scope = zend_get_executed_scope();
+	}
+	if( ( scope != Transliterator_ce_ptr ) &&
 		( zend_binary_strcmp( "id", sizeof( "id" ) - 1,
 		Z_STRVAL_P( member ), Z_STRLEN_P( member ) ) == 0 ) )
 	{
-		php_error_docref0( NULL TSRMLS_CC, E_WARNING, "The property \"id\" is read-only" );
+		php_error_docref(NULL, E_WARNING, "The property \"id\" is read-only" );
 	}
 	else
 	{
-#if PHP_VERSION_ID < 50399
-		std_object_handlers.write_property( object, member, value TSRMLS_CC );
-#else
-		std_object_handlers.write_property( object, member, value, key TSRMLS_CC );
-#endif
+		value = zend_std_write_property( object, member, value, cache_slot );
 	}
 
 	TRANSLITERATOR_PROPERTY_HANDLER_EPILOG;
+
+	return value;
 }
 /* }}} */
 
@@ -358,27 +303,18 @@ ZEND_BEGIN_ARG_INFO_EX( ainfo_trans_create_from_rules, 0, 0, 1 )
 	ZEND_ARG_INFO( 0, direction )
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX( ainfo_trans_create_inverse, 0, 0, 1 )
-	ZEND_ARG_OBJ_INFO( 0, orig_trans, Transliterator, 0 )
-ZEND_END_ARG_INFO()
-
 ZEND_BEGIN_ARG_INFO_EX( ainfo_trans_me_transliterate, 0, 0, 1 )
 	ZEND_ARG_INFO( 0, subject )
 	ZEND_ARG_INFO( 0, start )
 	ZEND_ARG_INFO( 0, end )
 ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX( ainfo_trans_error, 0, 0, 1 )
-	ZEND_ARG_OBJ_INFO( 0, trans, Transliterator, 0 )
-ZEND_END_ARG_INFO()
-
 /* }}} */
 
 /* {{{ Transliterator_class_functions
  * Every 'Transliterator' class method has an entry in this table
  */
-zend_function_entry Transliterator_class_functions[] = {
-	PHP_ME( Transliterator,			__construct,						ainfo_trans_void,				ZEND_ACC_PRIVATE | ZEND_ACC_CTOR | ZEND_ACC_FINAL )
+static const zend_function_entry Transliterator_class_functions[] = {
+	PHP_ME( Transliterator,			__construct,						ainfo_trans_void,				ZEND_ACC_PRIVATE | ZEND_ACC_FINAL )
 	PHP_ME_MAPPING( create,			transliterator_create,				ainfo_trans_create,				ZEND_ACC_STATIC |ZEND_ACC_PUBLIC )
 	PHP_ME_MAPPING( createFromRules,transliterator_create_from_rules,	ainfo_trans_create_from_rules,	ZEND_ACC_STATIC | ZEND_ACC_PUBLIC )
 	PHP_ME_MAPPING( createInverse,	transliterator_create_inverse,		ainfo_trans_void,				ZEND_ACC_PUBLIC )
@@ -393,16 +329,18 @@ zend_function_entry Transliterator_class_functions[] = {
 /* {{{ transliterator_register_Transliterator_class
  * Initialize 'Transliterator' class
  */
-void transliterator_register_Transliterator_class( TSRMLS_D )
+void transliterator_register_Transliterator_class( void )
 {
 	zend_class_entry ce;
 
 	/* Create and register 'Transliterator' class. */
 	INIT_CLASS_ENTRY( ce, "Transliterator", Transliterator_class_functions );
 	ce.create_object = Transliterator_object_create;
-	Transliterator_ce_ptr = zend_register_internal_class( &ce TSRMLS_CC );
-	memcpy( &Transliterator_handlers, zend_get_std_object_handlers(),
+	Transliterator_ce_ptr = zend_register_internal_class( &ce );
+	memcpy( &Transliterator_handlers, &std_object_handlers,
 		sizeof Transliterator_handlers );
+	Transliterator_handlers.offset = XtOffsetOf(Transliterator_object, zo);
+	Transliterator_handlers.free_obj = Transliterator_objects_free;
 	Transliterator_handlers.clone_obj = Transliterator_clone_obj;
 	Transliterator_handlers.get_property_ptr_ptr = Transliterator_get_property_ptr_ptr;
 	Transliterator_handlers.read_property = Transliterator_read_property;
@@ -417,18 +355,9 @@ void transliterator_register_Transliterator_class( TSRMLS_D )
 		return;
 	}
 	zend_declare_property_null( Transliterator_ce_ptr,
-		"id", sizeof( "id" ) - 1, ZEND_ACC_PUBLIC TSRMLS_CC );
+		"id", sizeof( "id" ) - 1, ZEND_ACC_PUBLIC );
 
 	/* constants are declared in transliterator_register_constants, called from MINIT */
 
 }
 /* }}} */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
