@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -27,7 +27,7 @@
 
 #include <zend_exceptions.h>
 
-static int create_transliterator( char *str_id, int str_id_len, long direction, zval *object TSRMLS_DC )
+static int create_transliterator( char *str_id, size_t str_id_len, zend_long direction, zval *object )
 {
 	Transliterator_object *to;
 	UChar	              *ustr_id    = NULL;
@@ -35,12 +35,12 @@ static int create_transliterator( char *str_id, int str_id_len, long direction,
 	UTransliterator       *utrans;
 	UParseError           parse_error   = {0, -1};
 
-	intl_error_reset( NULL TSRMLS_CC );
+	intl_error_reset( NULL );
 
 	if( ( direction != TRANSLITERATOR_FORWARD ) && (direction != TRANSLITERATOR_REVERSE ) )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_create: invalid direction", 0 TSRMLS_CC );
+			"transliterator_create: invalid direction", 0 );
 		return FAILURE;
 	}
 
@@ -51,9 +51,9 @@ static int create_transliterator( char *str_id, int str_id_len, long direction,
 	intl_convert_utf8_to_utf16( &ustr_id, &ustr_id_len, str_id, str_id_len, TRANSLITERATOR_ERROR_CODE_P( to ) );
 	if( U_FAILURE( TRANSLITERATOR_ERROR_CODE( to ) ) )
 	{
-		intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) TSRMLS_CC );
-		intl_error_set_custom_msg( NULL, "String conversion of id to UTF-16 failed", 0 TSRMLS_CC );
-		zval_dtor( object );
+		intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) );
+		intl_error_set_custom_msg( NULL, "String conversion of id to UTF-16 failed", 0 );
+		zval_ptr_dtor( object );
 		return FAILURE;
 	}
 
@@ -63,34 +63,34 @@ static int create_transliterator( char *str_id, int str_id_len, long direction,
 	if (ustr_id) {
 		efree( ustr_id );
 	}
-	
+
 	if( U_FAILURE( TRANSLITERATOR_ERROR_CODE( to ) ) )
 	{
 		char *buf = NULL;
-		intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) TSRMLS_CC );
+		intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) );
 		spprintf( &buf, 0, "transliterator_create: unable to open ICU transliterator"
 			" with id \"%s\"", str_id );
 		if( buf == NULL ) {
 			intl_error_set_custom_msg( NULL,
-				"transliterator_create: unable to open ICU transliterator", 0 TSRMLS_CC );
+				"transliterator_create: unable to open ICU transliterator", 0 );
 		}
 		else
 		{
-			intl_error_set_custom_msg( NULL, buf, /* copy message */ 1 TSRMLS_CC );
+			intl_error_set_custom_msg( NULL, buf, /* copy message */ 1 );
 			efree( buf );
 		}
-		zval_dtor( object );
+		zval_ptr_dtor( object );
 		return FAILURE;
 	}
-	
-	transliterator_object_construct( object, utrans, TRANSLITERATOR_ERROR_CODE_P( to ) TSRMLS_CC );
+
+	transliterator_object_construct( object, utrans, TRANSLITERATOR_ERROR_CODE_P( to ) );
 	/* no need to close the transliterator manually on construction error */
 	if( U_FAILURE( TRANSLITERATOR_ERROR_CODE( to ) ) )
 	{
-		intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) TSRMLS_CC );
+		intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) );
 		intl_error_set_custom_msg( NULL,
-			"transliterator_create: internal constructor call failed", 0 TSRMLS_CC );
-		zval_dtor( object );
+			"transliterator_create: internal constructor call failed", 0 );
+		zval_ptr_dtor( object );
 		return FAILURE;
 	}
 
@@ -103,28 +103,28 @@ static int create_transliterator( char *str_id, int str_id_len, long direction,
  */
 PHP_FUNCTION( transliterator_create )
 {
-	char  *str_id;
-	int   str_id_len;
-	long  direction   = TRANSLITERATOR_FORWARD;
+	char     *str_id;
+	size_t    str_id_len;
+	zend_long direction   = TRANSLITERATOR_FORWARD;
 	int res;
 
 	TRANSLITERATOR_METHOD_INIT_VARS;
-	
+
 	(void) to; /* unused */
 
-	if( zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "s|l",
+	if( zend_parse_parameters( ZEND_NUM_ARGS(), "s|l",
 		&str_id, &str_id_len, &direction ) == FAILURE )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_create: bad arguments", 0 TSRMLS_CC );
+			"transliterator_create: bad arguments", 0 );
 		RETURN_NULL();
 	}
 
 	object = return_value;
-	res = create_transliterator( str_id, str_id_len, direction, object TSRMLS_CC );
+	res = create_transliterator( str_id, str_id_len, direction, object );
 	if( res == FAILURE )
 		RETURN_NULL();
-	
+
 	/* success, leave return_value as it is (set by create_transliterator) */
 }
 /* }}} */
@@ -136,28 +136,28 @@ PHP_FUNCTION( transliterator_create )
 PHP_FUNCTION( transliterator_create_from_rules )
 {
 	char		    *str_rules;
-	int             str_rules_len;
+	size_t          str_rules_len;
 	UChar		    *ustr_rules    = NULL;
 	int32_t         ustr_rules_len = 0;
-	long            direction      = TRANSLITERATOR_FORWARD;
+	zend_long       direction      = TRANSLITERATOR_FORWARD;
 	UParseError     parse_error    = {0, -1};
 	UTransliterator *utrans;
 	UChar           id[] = {0x52, 0x75, 0x6C, 0x65, 0x73, 0x54, 0x72,
 					       0x61, 0x6E, 0x73, 0x50, 0x48, 0x50, 0}; /* RulesTransPHP */
 	TRANSLITERATOR_METHOD_INIT_VARS;
 
-	if( zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "s|l",
+	if( zend_parse_parameters( ZEND_NUM_ARGS(), "s|l",
 		&str_rules, &str_rules_len, &direction ) == FAILURE )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_create_from_rules: bad arguments", 0 TSRMLS_CC );
+			"transliterator_create_from_rules: bad arguments", 0 );
 		RETURN_NULL();
 	}
 
 	if( ( direction != TRANSLITERATOR_FORWARD ) && (direction != TRANSLITERATOR_REVERSE ) )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_create_from_rules: invalid direction", 0 TSRMLS_CC );
+			"transliterator_create_from_rules: invalid direction", 0 );
 		RETURN_NULL();
 	}
 
@@ -169,7 +169,7 @@ PHP_FUNCTION( transliterator_create_from_rules )
 		str_rules, str_rules_len, TRANSLITERATOR_ERROR_CODE_P( to ) );
 	/* (I'm not a big fan of non-obvious flow control macros ).
 	 * This one checks the error value, destroys object and returns false */
-	INTL_CTOR_CHECK_STATUS( to, "String conversion of rules to UTF-16 failed" );
+	INTL_METHOD_CHECK_STATUS_OR_NULL( to, "String conversion of rules to UTF-16 failed" );
 
 	/* Open ICU Transliterator. */
 	utrans = utrans_openU( id, ( sizeof( id ) - 1 ) / ( sizeof( *id ) ), (UTransDirection ) direction,
@@ -177,27 +177,27 @@ PHP_FUNCTION( transliterator_create_from_rules )
 	if (ustr_rules) {
 		efree( ustr_rules );
 	}
-	
-	intl_error_set_code( NULL, INTL_DATA_ERROR_CODE( to ) TSRMLS_CC );
+
+	intl_error_set_code( NULL, INTL_DATA_ERROR_CODE( to ) );
 	if( U_FAILURE( INTL_DATA_ERROR_CODE( to ) ) )
 	{
 		char *msg = NULL;
 		smart_str parse_error_str;
 		parse_error_str = intl_parse_error_to_string( &parse_error );
 		spprintf( &msg, 0, "transliterator_create_from_rules: unable to "
-			"create ICU transliterator from rules (%s)", parse_error_str.c );
+			"create ICU transliterator from rules (%s)", parse_error_str.s? ZSTR_VAL(parse_error_str.s) : "" );
 		smart_str_free( &parse_error_str );
 		if( msg != NULL )
 		{
-			intl_errors_set_custom_msg( INTL_DATA_ERROR_P( to ), msg, 1 TSRMLS_CC );
+			intl_errors_set_custom_msg( INTL_DATA_ERROR_P( to ), msg, 1 );
 			efree( msg );
 		}
-		zval_dtor( return_value );
+		zval_ptr_dtor( return_value );
 		RETURN_NULL();
     }
-	transliterator_object_construct( object, utrans, TRANSLITERATOR_ERROR_CODE_P( to ) TSRMLS_CC );
+	transliterator_object_construct( object, utrans, TRANSLITERATOR_ERROR_CODE_P( to ) );
 	/* no need to close the transliterator manually on construction error */
-	INTL_CTOR_CHECK_STATUS( to, "transliterator_create_from_rules: internal constructor call failed" );
+	INTL_METHOD_CHECK_STATUS_OR_NULL( to, "transliterator_create_from_rules: internal constructor call failed" );
 }
 /* }}} */
 
@@ -211,11 +211,11 @@ PHP_FUNCTION( transliterator_create_inverse )
 	UTransliterator       *utrans;
 	TRANSLITERATOR_METHOD_INIT_VARS;
 
-	if( zend_parse_method_parameters( ZEND_NUM_ARGS() TSRMLS_CC, getThis(), "O",
+	if( zend_parse_method_parameters( ZEND_NUM_ARGS(), getThis(), "O",
 		&object, Transliterator_ce_ptr ) == FAILURE )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_create_inverse: bad arguments", 0 TSRMLS_CC );
+			"transliterator_create_inverse: bad arguments", 0 );
 		RETURN_NULL();
 	}
 
@@ -225,13 +225,13 @@ PHP_FUNCTION( transliterator_create_inverse )
 	object = return_value;
 	object_init_ex( object, Transliterator_ce_ptr );
 	TRANSLITERATOR_METHOD_FETCH_OBJECT_NO_CHECK; /* change "to" into new object (from "object" ) */
-	
+
 	utrans = utrans_openInverse( to_orig->utrans, TRANSLITERATOR_ERROR_CODE_P( to ) );
-	INTL_CTOR_CHECK_STATUS( to, "transliterator_create_inverse: could not create "
+	INTL_METHOD_CHECK_STATUS_OR_NULL( to, "transliterator_create_inverse: could not create "
 		"inverse ICU transliterator" );
-	transliterator_object_construct( object, utrans, TRANSLITERATOR_ERROR_CODE_P( to ) TSRMLS_CC );
+	transliterator_object_construct( object, utrans, TRANSLITERATOR_ERROR_CODE_P( to ) );
 	/* no need to close the transliterator manually on construction error */
-	INTL_CTOR_CHECK_STATUS( to, "transliterator_create: internal constructor call failed" );
+	INTL_METHOD_CHECK_STATUS_OR_NULL( to, "transliterator_create: internal constructor call failed" );
 }
 /* }}} */
 
@@ -245,8 +245,8 @@ PHP_FUNCTION( transliterator_list_ids )
 	const UChar	  *elem;
 	int32_t		  elem_len;
 	UErrorCode	  status = U_ZERO_ERROR;
-	
-	intl_error_reset( NULL TSRMLS_CC );
+
+	intl_error_reset( NULL );
 
 	if( zend_parse_parameters_none() == FAILURE )
 	{
@@ -254,7 +254,7 @@ PHP_FUNCTION( transliterator_list_ids )
 		 * null on bad parameter types, except on constructors and factory
 		 * methods */
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_list_ids: bad arguments", 0 TSRMLS_CC );
+			"transliterator_list_ids: bad arguments", 0 );
 		RETURN_FALSE;
 	}
 
@@ -265,30 +265,26 @@ PHP_FUNCTION( transliterator_list_ids )
 	array_init( return_value );
 	while( (elem = uenum_unext( en, &elem_len, &status )) )
 	{
-		char *el_char = NULL;
-		int  el_len   = 0;
+		zend_string *el = intl_convert_utf16_to_utf8(elem, elem_len, &status );
 
-		intl_convert_utf16_to_utf8( &el_char, &el_len, elem, elem_len, &status );
-
-		if( U_FAILURE( status ) )
+		if( !el )
 		{
-			efree( el_char );
 			break;
 		}
 		else
 		{
-			add_next_index_stringl( return_value, el_char, el_len, 0 );
+			add_next_index_str( return_value, el);
 		}
 	}
 	uenum_close( en );
 
-	intl_error_set_code( NULL, status TSRMLS_CC );
+	intl_error_set_code( NULL, status );
 	if( U_FAILURE( status ) )
 	{
-		zval_dtor( return_value );
+		zend_array_destroy( Z_ARR_P(return_value) );
 		RETVAL_FALSE;
 		intl_error_set_custom_msg( NULL, "transliterator_list_ids: "
-			"Failed to build array of registered transliterators", 0 TSRMLS_CC );
+			"Failed to build array of registered transliterators", 0 );
 	}
 }
 /* }}} */
@@ -301,71 +297,70 @@ PHP_FUNCTION( transliterator_transliterate )
 	char	    *str;
 	UChar		*ustr		= NULL,
 				*uresult	= NULL;
-	int			str_len;
+	size_t	    str_len;
 	int32_t		ustr_len	= 0,
 				capacity,
 				uresult_len;
-	long		start		= 0,
+	zend_long	start		= 0,
 				limit		= -1;
-	int			success     = 0,
-				temp_trans  = 0;
+	int			success     = 0;
+	zval 		tmp_object;
 	TRANSLITERATOR_METHOD_INIT_VARS;
 
 	object = getThis();
+	ZVAL_UNDEF(&tmp_object);
 
 	if( object == NULL )
 	{
 		/* in non-OOP version, accept both a transliterator and a string */
-		zval **arg1;
-		if( zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "Zs|ll",
+		zval *arg1;
+		if( zend_parse_parameters( ZEND_NUM_ARGS(), "zs|ll",
 			&arg1, &str, &str_len, &start, &limit ) == FAILURE )
 		{
 			intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-				"transliterator_transliterate: bad arguments", 0 TSRMLS_CC );
+				"transliterator_transliterate: bad arguments", 0 );
 			RETURN_FALSE;
 		}
-		
-		if( Z_TYPE_PP( arg1 ) == IS_OBJECT &&
-			instanceof_function( Z_OBJCE_PP( arg1 ), Transliterator_ce_ptr TSRMLS_CC ) )
+
+		if( Z_TYPE_P( arg1 ) == IS_OBJECT &&
+			instanceof_function( Z_OBJCE_P( arg1 ), Transliterator_ce_ptr ) )
 		{
-			object = *arg1;
+			object = arg1;
 		}
 		else
 		{ /* not a transliterator object as first argument */
 			int res;
-			if(Z_TYPE_PP( arg1 ) != IS_STRING )
-			{
-				SEPARATE_ZVAL( arg1 );
-				convert_to_string( *arg1 );
+			if( !try_convert_to_string( arg1 ) ) {
+				return;
 			}
-			ALLOC_INIT_ZVAL( object );
-			temp_trans = 1;
-			res = create_transliterator( Z_STRVAL_PP( arg1 ), Z_STRLEN_PP( arg1 ),
-					TRANSLITERATOR_FORWARD, object TSRMLS_CC );
+			object = &tmp_object;
+			res = create_transliterator( Z_STRVAL_P( arg1 ), Z_STRLEN_P( arg1 ),
+					TRANSLITERATOR_FORWARD, object );
 			if( res == FAILURE )
 			{
-				char *message = intl_error_get_message( NULL TSRMLS_CC );
-				php_error_docref0( NULL TSRMLS_CC, E_WARNING, "Could not create "
-					"transliterator with ID \"%s\" (%s)", Z_STRVAL_PP( arg1 ), message );
-				efree( message );
+				zend_string *message = intl_error_get_message( NULL );
+				php_error_docref(NULL, E_WARNING, "Could not create "
+					"transliterator with ID \"%s\" (%s)", Z_STRVAL_P( arg1 ), ZSTR_VAL(message) );
+				zend_string_free( message );
+				ZVAL_UNDEF(&tmp_object);
 				/* don't set U_ILLEGAL_ARGUMENT_ERROR to allow fetching of inner error */
 				goto cleanup;
 			}
 		}
 	}
-	else if( zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "s|ll",
+	else if( zend_parse_parameters( ZEND_NUM_ARGS(), "s|ll",
 		&str, &str_len, &start, &limit ) == FAILURE )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_transliterate: bad arguments", 0 TSRMLS_CC );
+			"transliterator_transliterate: bad arguments", 0 );
 		RETURN_FALSE;
 	}
-	
+
 	if( limit < -1 )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
 			"transliterator_transliterate: \"end\" argument should be "
-			"either non-negative or -1", 0 TSRMLS_CC );
+			"either non-negative or -1", 0 );
 		RETURN_FALSE;
 	}
 
@@ -373,14 +368,14 @@ PHP_FUNCTION( transliterator_transliterate )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
 			"transliterator_transliterate: \"start\" argument should be "
-			"non-negative and not bigger than \"end\" (if defined)", 0 TSRMLS_CC );
+			"non-negative and not bigger than \"end\" (if defined)", 0 );
 		RETURN_FALSE;
 	}
 
 	/* end argument parsing/validation */
 
 	TRANSLITERATOR_METHOD_FETCH_OBJECT;
-	
+
 	intl_convert_utf8_to_utf16( &ustr, &ustr_len, str, str_len,
 		TRANSLITERATOR_ERROR_CODE_P( to ) );
 	INTL_METHOD_CHECK_STATUS( to, "String conversion of string to UTF-16 failed" );
@@ -397,7 +392,7 @@ PHP_FUNCTION( transliterator_transliterate )
 		if(msg != NULL )
 		{
 			intl_errors_set( TRANSLITERATOR_ERROR_P( to ), U_ILLEGAL_ARGUMENT_ERROR,
-				msg, 1 TSRMLS_CC );
+				msg, 1 );
 			efree( msg );
 		}
 		RETVAL_FALSE;
@@ -422,20 +417,20 @@ PHP_FUNCTION( transliterator_transliterate )
 			uresult = safe_emalloc( uresult_len, sizeof( UChar ), 1 * sizeof( UChar ) );
 			capacity = uresult_len + 1;
 
-			intl_error_reset( TRANSLITERATOR_ERROR_P( to ) TSRMLS_CC );
+			intl_error_reset( TRANSLITERATOR_ERROR_P( to ) );
 		}
 		else if(TRANSLITERATOR_ERROR_CODE( to ) == U_STRING_NOT_TERMINATED_WARNING )
 		{
 			uresult = safe_erealloc( uresult, uresult_len, sizeof( UChar ), 1 * sizeof( UChar ) );
-			
-			intl_error_reset( TRANSLITERATOR_ERROR_P( to ) TSRMLS_CC );
+
+			intl_error_reset( TRANSLITERATOR_ERROR_P( to ) );
 			break;
 		}
 		else if( U_FAILURE( TRANSLITERATOR_ERROR_CODE( to ) ) )
 		{
-			intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) TSRMLS_CC );
+			intl_error_set_code( NULL, TRANSLITERATOR_ERROR_CODE( to ) );
 			intl_errors_set_custom_msg( TRANSLITERATOR_ERROR_P( to ),
-				"transliterator_transliterate: transliteration failed", 0 TSRMLS_CC );
+				"transliterator_transliterate: transliteration failed", 0 );
 			goto cleanup;
 		}
 		else
@@ -443,7 +438,7 @@ PHP_FUNCTION( transliterator_transliterate )
 	}
 
 	uresult[uresult_len] = (UChar) 0;
-	
+
 	success = 1;
 
 cleanup:
@@ -461,8 +456,7 @@ cleanup:
 		RETVAL_FALSE;
 	}
 
-	if (temp_trans )
-		zval_ptr_dtor( &object );
+	zval_ptr_dtor( &tmp_object );
 }
 /* }}} */
 
@@ -471,7 +465,7 @@ PHP_METHOD( Transliterator, __construct )
 	/* this constructor shouldn't be called as it's private */
 	zend_throw_exception( NULL,
 		"An object of this type cannot be created with the new operator.",
-		0 TSRMLS_CC );
+		0 );
 }
 
 /* {{{ proto int transliterator_get_error_code( Transliterator trans )
@@ -482,21 +476,21 @@ PHP_FUNCTION( transliterator_get_error_code )
 {
 	TRANSLITERATOR_METHOD_INIT_VARS
 
-	if( zend_parse_method_parameters( ZEND_NUM_ARGS() TSRMLS_CC, getThis(), "O",
+	if( zend_parse_method_parameters( ZEND_NUM_ARGS(), getThis(), "O",
 		&object, Transliterator_ce_ptr ) == FAILURE )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_get_error_code: unable to parse input params", 0 TSRMLS_CC );
+			"transliterator_get_error_code: unable to parse input params", 0 );
 
 		RETURN_FALSE;
 	}
 
 	/* Fetch the object (without resetting its last error code ). */
-	to = zend_object_store_get_object( object TSRMLS_CC );
+	to = Z_INTL_TRANSLITERATOR_P( object );
 	if (to == NULL )
 		RETURN_FALSE;
 
-	RETURN_LONG( (long) TRANSLITERATOR_ERROR_CODE( to ) );
+	RETURN_LONG( (zend_long) TRANSLITERATOR_ERROR_CODE( to ) );
 }
 /* }}} */
 
@@ -507,36 +501,26 @@ PHP_FUNCTION( transliterator_get_error_code )
  */
 PHP_FUNCTION( transliterator_get_error_message )
 {
-	const char* message = NULL;
+	zend_string* message = NULL;
 	TRANSLITERATOR_METHOD_INIT_VARS
 
-	if( zend_parse_method_parameters( ZEND_NUM_ARGS() TSRMLS_CC, getThis(), "O",
+	if( zend_parse_method_parameters( ZEND_NUM_ARGS(), getThis(), "O",
 		&object, Transliterator_ce_ptr ) == FAILURE )
 	{
 		intl_error_set( NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"transliterator_get_error_message: unable to parse input params", 0 TSRMLS_CC );
+			"transliterator_get_error_message: unable to parse input params", 0 );
 
 		RETURN_FALSE;
 	}
 
 
 	/* Fetch the object (without resetting its last error code ). */
-	to = zend_object_store_get_object( object TSRMLS_CC );
+	to = Z_INTL_TRANSLITERATOR_P( object );
 	if (to == NULL )
 		RETURN_FALSE;
 
 	/* Return last error message. */
-	message = intl_error_get_message( TRANSLITERATOR_ERROR_P( to ) TSRMLS_CC );
-	RETURN_STRING( message, 0 );
+	message = intl_error_get_message( TRANSLITERATOR_ERROR_P( to ) );
+	RETURN_STR( message );
 }
 /* }}} */
-
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
