@@ -3,6 +3,7 @@
 #include "intl_convert.h"
 
 #include <unicode/uchar.h>
+#include <unicode/utf8.h>
 
 #define IC_METHOD(mname) PHP_METHOD(IntlChar, mname)
 
@@ -141,7 +142,7 @@ IC_METHOD(getIntPropertyMinValue) {
 }
 /* }}} */
 
-/* {{{ proto int IntlChar::getIntPropertyMxValue(int $property) */
+/* {{{ proto int IntlChar::getIntPropertyMaxValue(int $property) */
 ZEND_BEGIN_ARG_INFO_EX(getIntPropertyMaxValue_arginfo, 0, ZEND_RETURN_VALUE, 1)
 	ZEND_ARG_INFO(0, property)
 ZEND_END_ARG_INFO();
@@ -188,7 +189,7 @@ static UBool enumCharType_callback(enumCharType_data *context,
 	zval args[3];
 
 	ZVAL_NULL(&retval);
-	/* Note that $start is INclusive, whiel $limit is EXclusive
+	/* Note that $start is INclusive, while $limit is EXclusive
 	 * Therefore (0, 32, 15) means CPs 0..31 are of type 15
 	 */
 	ZVAL_LONG(&args[0], start);
@@ -202,10 +203,10 @@ static UBool enumCharType_callback(enumCharType_data *context,
 	if (zend_call_function(&context->fci, &context->fci_cache) == FAILURE) {
 		intl_error_set_code(NULL, U_INTERNAL_PROGRAM_ERROR);
 		intl_errors_set_custom_msg(NULL, "enumCharTypes callback failed", 0);
-		zval_dtor(&retval);
+		zval_ptr_dtor(&retval);
 		return 0;
 	}
-	zval_dtor(&retval);
+	zval_ptr_dtor(&retval);
 	return 1;
 }
 IC_METHOD(enumCharTypes) {
@@ -258,7 +259,7 @@ IC_METHOD(charName) {
 	error = U_ZERO_ERROR;
 	buffer_len = u_charName(cp, (UCharNameChoice)nameChoice, ZSTR_VAL(buffer), ZSTR_LEN(buffer) + 1, &error);
 	if (U_FAILURE(error)) {
-		zend_string_free(buffer);
+		zend_string_efree(buffer);
 		INTL_CHECK_STATUS_OR_NULL(error, "Failure getting character name");
 	}
 	RETURN_NEW_STR(buffer);
@@ -316,12 +317,12 @@ static UBool enumCharNames_callback(enumCharNames_data *context,
 	if (zend_call_function(&context->fci, &context->fci_cache) == FAILURE) {
 		intl_error_set_code(NULL, U_INTERNAL_PROGRAM_ERROR);
 		intl_error_set_custom_msg(NULL, "enumCharNames callback failed", 0);
-		zval_dtor(&retval);
-		zval_dtor(&args[2]);
+		zval_ptr_dtor(&retval);
+		zval_ptr_dtor_str(&args[2]);
 		return 0;
 	}
-	zval_dtor(&retval);
-	zval_dtor(&args[2]);
+	zval_ptr_dtor(&retval);
+	zval_ptr_dtor_str(&args[2]);
 	return 1;
 }
 IC_METHOD(enumCharNames) {
@@ -665,7 +666,7 @@ IC_CHAR_METHOD_CHAR(getBidiPairedBracket)
 #undef IC_CHAR_METHOD_CHAR
 /* }}} */
 
-static zend_function_entry intlchar_methods[] = {
+static const zend_function_entry intlchar_methods[] = {
 #define IC_ME(mname) PHP_ME(IntlChar, mname, mname##_arginfo, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
 	IC_ME(chr)
 	IC_ME(ord)
@@ -744,8 +745,6 @@ int php_uchar_minit(INIT_FUNC_ARGS) {
 	zend_declare_class_constant_string(ce, "UNICODE_VERSION", sizeof("UNICODE_VERISON")-1, U_UNICODE_VERSION);
 	IC_CONSTL("CODEPOINT_MIN", UCHAR_MIN_VALUE)
 	IC_CONSTL("CODEPOINT_MAX", UCHAR_MAX_VALUE)
-	IC_CONSTL("FOLD_CASE_DEFAULT", U_FOLD_CASE_DEFAULT)
-	IC_CONSTL("FOLD_CASE_EXCLUDE_SPECIAL_I", U_FOLD_CASE_EXCLUDE_SPECIAL_I)
 	zend_declare_class_constant_double(ce, "NO_NUMERIC_VALUE", sizeof("NO_NUMERIC_VALUE")-1, U_NO_NUMERIC_VALUE);
 
 	/* All enums used by the uchar APIs.  There are a LOT of them,
@@ -778,4 +777,3 @@ int php_uchar_minit(INIT_FUNC_ARGS) {
 
 	return SUCCESS;
 }
-
