@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,20 +30,28 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_PHP_JSON_YY_HOME_DMITRY_PHP_PHP_MASTER_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
-# define YY_PHP_JSON_YY_HOME_DMITRY_PHP_PHP_MASTER_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
+#ifndef YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
+# define YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef PHP_JSON_YYDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define PHP_JSON_YYDEBUG 1
+#  else
+#   define PHP_JSON_YYDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define PHP_JSON_YYDEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined PHP_JSON_YYDEBUG */
+#if PHP_JSON_YYDEBUG
 extern int php_json_yydebug;
 #endif
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef PHP_JSON_YYTOKENTYPE
+# define PHP_JSON_YYTOKENTYPE
+  enum php_json_yytokentype
   {
     PHP_JSON_T_NUL = 258,
     PHP_JSON_T_TRUE = 259,
@@ -56,21 +64,11 @@ extern int php_json_yydebug;
     PHP_JSON_T_ERROR = 266
   };
 #endif
-/* Tokens.  */
-#define PHP_JSON_T_NUL 258
-#define PHP_JSON_T_TRUE 259
-#define PHP_JSON_T_FALSE 260
-#define PHP_JSON_T_INT 261
-#define PHP_JSON_T_DOUBLE 262
-#define PHP_JSON_T_STRING 263
-#define PHP_JSON_T_ESTRING 264
-#define PHP_JSON_T_EOI 265
-#define PHP_JSON_T_ERROR 266
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
-union YYSTYPE
+#if ! defined PHP_JSON_YYSTYPE && ! defined PHP_JSON_YYSTYPE_IS_DECLARED
+typedef union PHP_JSON_YYSTYPE PHP_JSON_YYSTYPE;
+union PHP_JSON_YYSTYPE
 {
 
 
@@ -82,14 +80,12 @@ union YYSTYPE
 
 
 };
-
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+# define PHP_JSON_YYSTYPE_IS_TRIVIAL 1
+# define PHP_JSON_YYSTYPE_IS_DECLARED 1
 #endif
 
 
 
 int php_json_yyparse (php_json_parser *parser);
 
-#endif /* !YY_PHP_JSON_YY_HOME_DMITRY_PHP_PHP_MASTER_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED  */
+#endif /* !YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED  */
