@@ -32,44 +32,44 @@
 #endif
 
 #include "mbfilter.h"
-#include "mbfilter_iso8859_2.h"
-#include "unicode_table_iso8859_2.h"
+#include "mbfilter_iso8859_6.h"
+#include "unicode_table_iso8859_6.h"
 
-static const char *mbfl_encoding_8859_2_aliases[] = {"ISO_8859-2", "latin2", NULL};
+static const char *mbfl_encoding_8859_6_aliases[] = {"ISO_8859-6", "arabic", NULL};
 
-const mbfl_encoding mbfl_encoding_8859_2 = {
-	mbfl_no_encoding_8859_2,
-	"ISO-8859-2",
-	"ISO-8859-2",
-	(const char *(*)[])&mbfl_encoding_8859_2_aliases,
+const mbfl_encoding mbfl_encoding_8859_6 = {
+	mbfl_no_encoding_8859_6,
+	"ISO-8859-6",
+	"ISO-8859-6",
+	(const char *(*)[])&mbfl_encoding_8859_6_aliases,
 	NULL,
 	MBFL_ENCTYPE_SBCS,
-	&vtbl_8859_2_wchar,
-	&vtbl_wchar_8859_2
+	&vtbl_8859_6_wchar,
+	&vtbl_wchar_8859_6
 };
 
-const struct mbfl_identify_vtbl vtbl_identify_8859_2 = {
-	mbfl_no_encoding_8859_2,
+const struct mbfl_identify_vtbl vtbl_identify_8859_6 = {
+	mbfl_no_encoding_8859_6,
 	mbfl_filt_ident_common_ctor,
 	mbfl_filt_ident_common_dtor,
 	mbfl_filt_ident_true
 };
 
-const struct mbfl_convert_vtbl vtbl_8859_2_wchar = {
-	mbfl_no_encoding_8859_2,
+const struct mbfl_convert_vtbl vtbl_8859_6_wchar = {
+	mbfl_no_encoding_8859_6,
 	mbfl_no_encoding_wchar,
 	mbfl_filt_conv_common_ctor,
 	mbfl_filt_conv_common_dtor,
-	mbfl_filt_conv_8859_2_wchar,
+	mbfl_filt_conv_8859_6_wchar,
 	mbfl_filt_conv_common_flush
 };
 
-const struct mbfl_convert_vtbl vtbl_wchar_8859_2 = {
+const struct mbfl_convert_vtbl vtbl_wchar_8859_6 = {
 	mbfl_no_encoding_wchar,
-	mbfl_no_encoding_8859_2,
+	mbfl_no_encoding_8859_6,
 	mbfl_filt_conv_common_ctor,
 	mbfl_filt_conv_common_dtor,
-	mbfl_filt_conv_wchar_8859_2,
+	mbfl_filt_conv_wchar_8859_6,
 	mbfl_filt_conv_common_flush
 };
 
@@ -77,20 +77,20 @@ const struct mbfl_convert_vtbl vtbl_wchar_8859_2 = {
 #define CK(statement)	do { if ((statement) < 0) return (-1); } while (0)
 
 /*
- * ISO-8859-2 => wchar
+ * ISO-8859-6 => wchar
  */
-int mbfl_filt_conv_8859_2_wchar(int c, mbfl_convert_filter *filter)
+int mbfl_filt_conv_8859_6_wchar(int c, mbfl_convert_filter *filter)
 {
 	int s;
 
 	if (c >= 0 && c < 0xa0) {
 		s = c;
 	} else if (c >= 0xa0 && c < 0x100) {
-		s = iso8859_2_ucs_table[c - 0xa0];
+		s = iso8859_6_ucs_table[c - 0xa0];
 		if (s <= 0) {
 			s = c;
 			s &= MBFL_WCSPLANE_MASK;
-			s |= MBFL_WCSPLANE_8859_2;
+			s |= MBFL_WCSPLANE_8859_6;
 		}
 	} else {
 		s = c;
@@ -104,9 +104,9 @@ int mbfl_filt_conv_8859_2_wchar(int c, mbfl_convert_filter *filter)
 }
 
 /*
- * wchar => ISO-8859-2
+ * wchar => ISO-8859-6
  */
-int mbfl_filt_conv_wchar_8859_2(int c, mbfl_convert_filter *filter)
+int mbfl_filt_conv_wchar_8859_6(int c, mbfl_convert_filter *filter)
 {
 	int s, n;
 
@@ -116,13 +116,13 @@ int mbfl_filt_conv_wchar_8859_2(int c, mbfl_convert_filter *filter)
 		s = -1;
 		n = 95;
 		while (n >= 0) {
-			if (c == iso8859_2_ucs_table[n]) {
+			if (c == iso8859_6_ucs_table[n]) {
 				s = 0xa0 + n;
 				break;
 			}
 			n--;
 		}
-		if (s <= 0 && (c & ~MBFL_WCSPLANE_MASK) == MBFL_WCSPLANE_8859_2) {
+		if (s <= 0 && (c & ~MBFL_WCSPLANE_MASK) == MBFL_WCSPLANE_8859_6) {
 			s = c & MBFL_WCSPLANE_MASK;
 		}
 	}
