@@ -1,5 +1,3 @@
-static const char rcsid[] = "#(@) $Id$";
-
 /*
 
 	   Encode or decode file as MIME base64 (RFC 1341)
@@ -57,9 +55,6 @@ void base64_encode_xmlrpc(struct buffer_st *b, const char *source, int length)
 {
   int i, hiteof = 0;
   int offset = 0;
-  int olen;
-
-  olen = 0;
 
   buffer_new(b);
 
