@@ -328,3 +328,17 @@ struct bug79096 bug79096(void)
   b.b = 1;
   return b;
 }
+
+void bug79532(off_t *array, size_t elems)
+{
+	int i;
+	for (i = 0; i < elems; i++) {
+		array[i] = i;
+	}
+}
+
+PHP_ZEND_TEST_API int *(*bug79177_cb)(void);
+void bug79177(void)
+{
+	bug79177_cb();
+}
