@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2018 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,8 +16,6 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id$ */
-
 #ifndef SYSLOG_H
 #define	SYSLOG_H
 #define WIN32_LEAN_AND_MEAN
@@ -73,15 +71,7 @@
 extern void closelog(void);
 extern void openlog(const char *, int, int);
 extern void syslog(int, const char *, ...);
+extern void vsyslog(int, const char *, va_list ap);
 
 
 #endif							/* SYSLOG_H */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: sw=4 ts=4 fdm=marker
- * vim<600: sw=4 ts=4
- */
